==> flusstools-0.2.8.tar.gz: flusstools-0.2.8/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "flusstools"
DESCRIPTION = "Analyze and design river ecosystems"
URL = "https://flusstools.readthedocs.io/"
EMAIL = "sebastian.schwindt@iws.uni-stuttgart.de"
AUTHOR = "FlussTeam"
REQUIRES_PYTHON = ">=3.8.0"
VERSION = "0.2.8"
LICENSE = "BSD License"
KEYWORDS = "rivers geo-spatial data processing numerical model validation"

# What packages are required for this module to be executed?
if "READTHEDOCS" in os.environ:
    print("RTD import enabled (ignore dependencies).")
    REQUIRED = []
else:
    REQUIRED = [
        "alphashape",
        "earthpy",
        "gdal",
        "geojson",
        "geopandas",
        "laspy",
        "mapclassify",
        "matplotlib",
        "numpy",
        "openpyxl",
        "pandas",
        "pillow",
        "pyshp",
        "rasterio",
        "rasterstats",
        "scipy",
        "shapely",
        "tabulate",
        # build updates from 2021-11-12
        "affine",
        "attrs",
        "click",
        "cligj",
        "cycler",
        "kiwisolver",
        "python-dateutil",
        "setuptools",
        "traitlets",
    ]

# What packages are optional?
EXTRAS = {
    # "fancy feature": ["django"],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system(
            "{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    keywords=KEYWORDS,
    url=URL,
    packages=find_packages(
        exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    # If your package is a single module, use this instead of "packages":
    # py_modules=["mypackage"],

    # entry_points={
    #     "console_scripts": ["mycli=mymodule:cli"],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license=LICENSE,
    project_urls={
        "Documentation": "https://flusstools.readthedocs.io/",
        "Funding": "https://www.uni-stuttgart.de/",
        "Source": "https://github.com/Ecohydraulics/flusstools",
        "Tracker": "https://github.com/Ecohydraulics/flusstools/issues",
    },
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: BSD License",
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy"
    ],
    # $ setup.py publish support.
    cmdclass={
        "upload": UploadCommand,
    },
)

==> flusstools-1.0.5.tar.gz: flusstools-1.0.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = "flusstools"
DESCRIPTION = "Analyze and design river ecosystems"
URL = "https://flusstools.readthedocs.io/"
EMAIL = "schwindt.water@gmail.com"
AUTHOR = "FlussTeam"
REQUIRES_PYTHON = ">=3.8.0"
VERSION = "1.0.5"
LICENSE = "BSD License"
KEYWORDS = "rivers geo-spatial data processing numerical model validation"

# What packages are required for this module to be executed?
if "READTHEDOCS" in os.environ:
    print("RTD import enabled (ignore dependencies).")
    REQUIRED = []
else:
    REQUIRED = [
        "alphashape",
        "earthpy",
        "gdal",
        "geojson",
        "geopandas",
        "laspy",
        "mapclassify",
        "matplotlib",
        "networkx",
        "numpy",
        "openpyxl",
        "pandas",
        "pillow",
        "pyshp",
        "rasterio",
        "rasterstats",
        "scipy",
        "shapely",
        "tabulate",
        # build updates from 2021-11-12
        "affine",
        "attrs",
        "click",
        "cligj",
        "cycler",
        "kiwisolver",
        "python-dateutil",
        "setuptools",
        "traitlets",
    ]

# What packages are optional?
EXTRAS = {
    # "fancy feature": ["django"],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system(
            "{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about["__version__"],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    keywords=KEYWORDS,
    url=URL,
    packages=find_packages(
        exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    # If your package is a single module, use this instead of "packages":
    # py_modules=["mypackage"],

    # entry_points={
    #     "console_scripts": ["mycli=mymodule:cli"],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license=LICENSE,
    project_urls={
        "Documentation": "https://flusstools.readthedocs.io/",
        "Funding": "https://hydro-informatics.com/",
        "Source": "https://github.com/Ecohydraulics/flusstools",
        "Tracker": "https://github.com/Ecohydraulics/flusstools/issues",
    },
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy"
    ],
    # $ setup.py publish support.
    cmdclass={
        "upload": UploadCommand,
    },
)
